@@ -12,10 +12,10 @@
 #include <QBuffer>
 #include <QDir>
 #include <QDirIterator>
-#include <QTemporaryDir>
-#include <QTest>
 #include <QNetworkReply>
 #include <QNetworkRequest>
+#include <QTemporaryDir>
+#include <QTest>
 #include <QVector>
 
 QTEST_MAIN(KCompressionDeviceTest)
@@ -46,15 +46,15 @@ QString KCompressionDeviceTest::formatExtension(KCompressionDevice::CompressionT
         return "tar.bz2";
     case KCompressionDevice::Xz:
         return "tar.xz";
+    case KCompressionDevice::Zstd:
+        return "tar.zst";
     case KCompressionDevice::None:
         return QString();
     }
     return QString(); // silence compiler warning
 }
 
-void KCompressionDeviceTest::setDeviceToArchive(
-        QIODevice *d,
-        KCompressionDevice::CompressionType type)
+void KCompressionDeviceTest::setDeviceToArchive(QIODevice *d, KCompressionDevice::CompressionType type)
 {
     KCompressionDevice *devRawPtr = new KCompressionDevice(d, true, type);
     archive.reset(new KTar(devRawPtr));
@@ -90,19 +90,17 @@ void KCompressionDeviceTest::testExtraction()
     QVERIFY(QDir("examples/tarlocalfiles").exists());
     QVERIFY(QDir("examples/unzipper").exists());
 
-    QVector<QString> fileList;
-    fileList
-            << QLatin1String("examples/bzip2gzip/CMakeLists.txt")
-            << QLatin1String("examples/bzip2gzip/main.cpp")
-            << QLatin1String("examples/helloworld/CMakeLists.txt")
-            << QLatin1String("examples/helloworld/helloworld.pro")
-            << QLatin1String("examples/helloworld/main.cpp")
-            << QLatin1String("examples/tarlocalfiles/CMakeLists.txt")
-            << QLatin1String("examples/tarlocalfiles/main.cpp")
-            << QLatin1String("examples/unzipper/CMakeLists.txt")
-            << QLatin1String("examples/unzipper/main.cpp");
+    const QStringList fileList = {QStringLiteral("examples/bzip2gzip/CMakeLists.txt"),
+                                  QStringLiteral("examples/bzip2gzip/main.cpp"),
+                                  QStringLiteral("examples/helloworld/CMakeLists.txt"),
+                                  QStringLiteral("examples/helloworld/helloworld.pro"),
+                                  QStringLiteral("examples/helloworld/main.cpp"),
+                                  QStringLiteral("examples/tarlocalfiles/CMakeLists.txt"),
+                                  QStringLiteral("examples/tarlocalfiles/main.cpp"),
+                                  QStringLiteral("examples/unzipper/CMakeLists.txt"),
+                                  QStringLiteral("examples/unzipper/main.cpp")};
 
-    for (const QString& s : qAsConst(fileList)) {
+    for (const QString &s : fileList) {
         QFileInfo extractedFile(s);
         QFileInfo sourceFile(QFINDTESTDATA("../" + s));
 
@@ -143,6 +141,15 @@ void KCompressionDeviceTest::testXzBufferedDevice()
 #endif
 }
 
+void KCompressionDeviceTest::testZstdBufferedDevice()
+{
+#ifdef HAVE_ZSTD_SUPPORT_FILE
+    testBufferedDevice(KCompressionDevice::Zstd);
+#else
+    QSKIP("This test needs zstd support");
+#endif
+}
+
 void KCompressionDeviceTest::testWriteErrorOnOpen()
 {
     // GIVEN
